@@ -81,7 +81,6 @@ class Debug():
         asyncio.run(event(**parameters))
 
     def _execute_class(self, event: callable, parameters: dict):
-        print(parameters)
         event(**parameters)
 
     def _execute_async(self, command):
@@ -108,7 +107,7 @@ if __name__ == "__main__":
             self.name = name
 
         @terminal()
-        def yo(self, a, b, c):
+        async def yo(self, a, b, c):
             print("plait", a, b, c)
 
     a = Test("a")
